# fastapi_helmet/settings.py
from pydantic import BaseModel


class HelmetSettings(BaseModel):
    x_content_type_options: bool = True
    x_frame_options: bool = True
    x_xss_protection: bool = True
    referrer_policy: bool = True
    content_security_policy: bool = True
    strict_transport_security: bool = True
    expect_ct: bool = True
    custom_headers: dict = {}



from starlette.responses import Response


class HelmetCore:
    def __init__(self, **options):
        self.options = options

    def set_headers(self, response: Response):
        headers = {
            "X-Content-Type-Options": "nosniff",
            "X-Frame-Options": "DENY",
            "X-XSS-Protection": "1; mode=block",
            "Referrer-Policy": "no-referrer",
            "Content-Security-Policy": "default-src 'self'",
            "Strict-Transport-Security": "max-age=63072000; includeSubDomains",
            "Expect-CT": "max-age=86400, enforce",
        }
        for header, value in headers.items():
            if self.options.get(header, True):
                response.headers[header] = value
        custom_headers = self.options.get("custom_headers", {})
        for header, value in custom_headers.items():
            response.headers[header] = value



# fastapi_helmet/middleware.py
from starlette.middleware.base import BaseHTTPMiddleware
from starlette.requests import Request
from starlette.responses import Response
from core import HelmetCore


class HelmetMiddleware(BaseHTTPMiddleware):
    def __init__(self, app, **options):
        super().__init__(app)
        self.helmet = HelmetCore(**options)

    async def dispatch(self, request: Request, call_next):
        response: Response = await call_next(request)
        self.helmet.set_headers(response)
        return response
